HeadOption class

Inheritance

Constructors

HeadOption()

Properties

abbr → String?
finalinherited
aliases → List<String>
finalinherited
allowed → Iterable<String>?
finalinherited
allowedHelp → Map<String, String>?
finalinherited
callback → void Function(String?)?
finalinherited
defaultsTo → String?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
help → String?
finalinherited
hide → bool
finalinherited
mandatory → bool
finalinherited
name → String
finalinherited
negatable → bool
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
splitCommas → bool?
finalinherited
type → OptionType
finalinherited
valueHelp → String?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods