AnalyzeResult class

Annotations
  • @immutable

Constructors

AnalyzeResult({required Severity severity, required String type, required String errorCode, required String filePath, required int line, required int column, required int length, required String errorMessage})
const

Properties

column → int
final
errorCode → String
final
errorMessage → String
final
filePath → String
final
hashCode → int
The hash code for this object.
no setteroverride
length → int
final
line → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
severity → Severity
final
type → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override