ExitStatus enum
- Inheritance
- Available extensions
Values
- success → const ExitStatus
- usage → const ExitStatus
- error → const ExitStatus
Properties
- code → int
-
Available on ExitStatus, provided by the ExitStatusExt extension
no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
flushThenExit(
) → Future< void> -
Available on ExitStatus, provided by the ExitStatusExt extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ExitStatus> - A constant List of the values in this enum, in order of their declaration.